# -*- coding: UTF-8 -*-
"""
NPM HELPER
"""

__version__ = '0.1'

BASE_URL = 'https://www.npmjs.com/search?q={query}&page={page}'

TABLE_HEADER = ('编号', '名称', '简介', '月下载量')
TABLE_ROW = ('index', 'name', 'desc', 'download')
